Crate mux_circuits

Crate mux_circuits 

This crate provides algorithms for building multiplexer circuits as well as a standard library of common operations.

Modules

add
Integer Adders
and
Bitwise-and
bitshift
Bitshift
comparisons
Integer comparisons.
error
Errors that can occur in this crate.
mul
Integer multipliers
neg
Integer negator
opt
Circuit optimizations.
or
Bitwise-or
sub
Integer subtractors
util
Misc operations on integers.

Structs

Bit
A bit containing the value true or false.
MuxCircuit
A DAG describing a multiplexer tree.
MuxCircuitInfo
Metrcs for a MuxCircuit
MuxInputs
The NodeIndexes of a MuxOp::Mux’s parent operations.

Enums

MuxEdgeInfo
The wires of the MuxCircuit connecting MuxOps.
MuxOp
The operations in a MuxCircuit. These operations are connected with MuxEdgeInfos.

Functions

convert_value_to_bits
Converts a value into a vector of bits.
test_mux_circuit
Run the given inputs through MuxCircuit and return the resuling output Bits