pub struct GraphQuery<'a, N, E>(pub &'a StableGraph<N, E>);Expand description
A wrapper for ascertaining the structure of the underlying graph.
This type is used in forward_traverse_mut callbacks.
Tuple Fields
0: &'a StableGraph<N, E>Implementations
Sourceimpl<'a, N, E> GraphQuery<'a, N, E>
impl<'a, N, E> GraphQuery<'a, N, E>
Sourcepub fn new(ir: &'a StableGraph<N, E>) -> Self
pub fn new(ir: &'a StableGraph<N, E>) -> Self
Creates a new GraphQuery from a reference to a
StableGraph.
Sourcepub fn neighbors_directed(
&self,
x: NodeIndex,
direction: Direction,
) -> Neighbors<'_, E>
pub fn neighbors_directed( &self, x: NodeIndex, direction: Direction, ) -> Neighbors<'_, E>
Gets information about the immediate parent or child nodes of the node at the given index.
Remarks
Direction::Outgoing gives children, while
Direction::Incoming gives parents.
Sourcepub fn edges_directed(
&self,
x: NodeIndex,
direction: Direction,
) -> Edges<'_, E, Directed>
pub fn edges_directed( &self, x: NodeIndex, direction: Direction, ) -> Edges<'_, E, Directed>
Gets edges pointing at the parent or child nodes of the node at the given index.
Remarks
Direction::Outgoing gives children, while
Direction::Incoming gives parents.