This crate provides algorithms for building multiplexer circuits as well as a standard library of common operations.
Modules
- add
- Integer Adders
- and
- Bitwise-and
- bitshift
- Bitshift
- comparisons
- Integer comparisons.
- error
- Errors that can occur in this crate.
- mul
- Integer multipliers
- neg
- Integer negator
- opt
- Circuit optimizations.
- or
- Bitwise-or
- sub
- Integer subtractors
- util
- Misc operations on integers.
Structs
- Bit
- A bit containing the value true or false.
- MuxCircuit
- A DAG describing a multiplexer tree.
- MuxCircuit
Info - Metrcs for a
MuxCircuit - MuxInputs
- The
NodeIndexes of aMuxOp::Mux’s parent operations.
Enums
- MuxEdge
Info - The wires of the
MuxCircuitconnectingMuxOps. - MuxOp
- The operations in a
MuxCircuit. These operations are connected withMuxEdgeInfos.
Functions
- convert_
value_ to_ bits - Converts a value into a vector of bits.
- test_
mux_ circuit - Run the given inputs through
MuxCircuitand return the resuling outputBits